#################################
Reading/storing pulsar parameters
#################################

CWInPy provides a :class:`~cwinpy.parfile.PulsarParameters` class for reading in,
and storing, Tempo-style pulsar parameter files. The class can also be used to
construct a set of parameters for a source. This class is based on, and designed to supercede, the
`PulsarParameters.py <https://lscsoft.docs.ligo.org/lalsuite/lalpulsar/classlalpulsar_1_1_pulsar_parameters_wrapper_1_1_pulsar_parameters_py.html>`_ structure in LALPulsar.

.. autoclass:: cwinpy.parfile.PulsarParameters
   :members:
